@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options of saving .svg file.',
                                   class => 'SvgSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,7 +128,7 @@ __PACKAGE__->method_documentation({
      'sheet_index' => {
      	datatype => 'int',
      	base_name => 'SheetIndex',
-     	description => '',
+     	description => 'Gets and sets which worksheet should be exported.  If the value is -1, the                active worksheet will be exported.',
      	format => '',
      	read_only => '',
      		},
