@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# DeleteDecryptWorkbookRequest.name :   ,
-# DeleteDecryptWorkbookRequest.encryption :   ,
-# DeleteDecryptWorkbookRequest.folder :   ,
-# DeleteDecryptWorkbookRequest.storageName :    
+# DeleteDecryptWorkbookRequest.name : The file name.  ,
+# DeleteDecryptWorkbookRequest.encryption : WorkbookEncryptionRequestEncryption parameters.  ,
+# DeleteDecryptWorkbookRequest.folder : The folder where the file is situated.  ,
+# DeleteDecryptWorkbookRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_decrypt_workbook' } = { 
-    	summary => '',
+    	summary => 'Excel files decryption.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -130,28 +130,28 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'encryption' => {
      	datatype => 'WorkbookEncryptionRequest',
      	base_name => 'encryption',
-     	description => '',
+     	description => 'WorkbookEncryptionRequestEncryption parameters.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
