@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetCellsRequest.name :   ,
-# GetWorksheetCellsRequest.sheetName :   ,
-# GetWorksheetCellsRequest.offest :   ,
-# GetWorksheetCellsRequest.count :   ,
-# GetWorksheetCellsRequest.folder :   ,
-# GetWorksheetCellsRequest.storageName :    
+# GetWorksheetCellsRequest.name : The file name.  ,
+# GetWorksheetCellsRequest.sheetName : The worksheet name.  ,
+# GetWorksheetCellsRequest.offest : Begginig offset.  ,
+# GetWorksheetCellsRequest.count : Maximum amount of cells in the response.  ,
+# GetWorksheetCellsRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetCellsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_cells' } = { 
-    	summary => '',
+    	summary => 'Retrieve cell descriptions in a specified format.',
         params => $params,
         returns => 'CellsResponse',
     };
@@ -140,42 +140,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'offest' => {
      	datatype => 'int',
      	base_name => 'offest',
-     	description => '',
+     	description => 'Begginig offset.',
      	format => '',
      	read_only => '',
      		},
      'count' => {
      	datatype => 'int',
      	base_name => 'count',
-     	description => '',
+     	description => 'Maximum amount of cells in the response.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
