@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -60,9 +60,11 @@ sub new {
 
 # Run Operation Request
 # PostMetadataRequest.File : File to upload  ,
-# PostMetadataRequest.cellsDocuments :   ,
-# PostMetadataRequest.password :   ,
-# PostMetadataRequest.checkExcelRestriction :    
+# PostMetadataRequest.cellsDocuments : document properties  ,
+# PostMetadataRequest.password : The password needed to open an Excel file.  ,
+# PostMetadataRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
+# PostMetadataRequest.outFormat : The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)  ,
+# PostMetadataRequest.region : The regional settings for workbook.   
 
 {
     my $params = {
@@ -73,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_metadata' } = { 
-    	summary => '',
+    	summary => 'Update document properties in Excel file, and save them is various formats.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -105,6 +107,14 @@ sub run_http_request {
 
     if(defined $self->check_excel_restriction){
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
+    }
+
+    if(defined $self->out_format){
+        $query_params->{'outFormat'} = $client->to_query_value($self->out_format);      
+    }
+
+    if(defined $self->region){
+        $query_params->{'region'} = $client->to_query_value($self->region);      
     } 
     my $_body_data;
 
@@ -141,21 +151,35 @@ __PACKAGE__->method_documentation({
      'cells_documents' => {
      	datatype => 'ARRAY[CellsDocumentProperty]',
      	base_name => 'cellsDocuments',
-     	description => '',
+     	description => 'document properties',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => '',
+     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	format => '',
+     	read_only => '',
+     		},
+     'out_format' => {
+     	datatype => 'string',
+     	base_name => 'outFormat',
+     	description => 'The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'region',
+     	description => 'The regional settings for workbook.',
      	format => '',
      	read_only => '',
      		},    
@@ -166,7 +190,9 @@ __PACKAGE__->attribute_map( {
     'file' => 'File',
     'cells_documents' => 'cellsDocuments',
     'password' => 'password',
-    'check_excel_restriction' => 'checkExcelRestriction' 
+    'check_excel_restriction' => 'checkExcelRestriction',
+    'out_format' => 'outFormat',
+    'region' => 'region' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
