@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,15 +59,15 @@ sub new {
 
 
 # Run Operation Request
-# PostPivotTableUpdatePivotFieldRequest.name :   ,
-# PostPivotTableUpdatePivotFieldRequest.sheetName :   ,
-# PostPivotTableUpdatePivotFieldRequest.pivotTableIndex :   ,
-# PostPivotTableUpdatePivotFieldRequest.pivotFieldIndex :   ,
-# PostPivotTableUpdatePivotFieldRequest.pivotFieldType :   ,
-# PostPivotTableUpdatePivotFieldRequest.pivotField :   ,
-# PostPivotTableUpdatePivotFieldRequest.needReCalculate :   ,
-# PostPivotTableUpdatePivotFieldRequest.folder :   ,
-# PostPivotTableUpdatePivotFieldRequest.storageName :    
+# PostPivotTableUpdatePivotFieldRequest.name : The file name.  ,
+# PostPivotTableUpdatePivotFieldRequest.sheetName : The worksheet name.  ,
+# PostPivotTableUpdatePivotFieldRequest.pivotTableIndex : The PivotTable index.  ,
+# PostPivotTableUpdatePivotFieldRequest.pivotFieldIndex : The pivot field index.  ,
+# PostPivotTableUpdatePivotFieldRequest.pivotFieldType : Represents PivotTable field type(Undefined/Row/Column/Page/Data).  ,
+# PostPivotTableUpdatePivotFieldRequest.pivotField : Represents pivot field.  ,
+# PostPivotTableUpdatePivotFieldRequest.needReCalculate : Whether the specific PivotTable calculate(true/false).  ,
+# PostPivotTableUpdatePivotFieldRequest.folder : The folder where the file is situated.  ,
+# PostPivotTableUpdatePivotFieldRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -78,7 +78,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_pivot_table_update_pivot_field' } = { 
-    	summary => '',
+    	summary => 'Update pivot field in the PivotTable.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -161,63 +161,63 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => '',
+     	description => 'The PivotTable index.',
      	format => '',
      	read_only => '',
      		},
      'pivot_field_index' => {
      	datatype => 'int',
      	base_name => 'pivotFieldIndex',
-     	description => '',
+     	description => 'The pivot field index.',
      	format => '',
      	read_only => '',
      		},
      'pivot_field_type' => {
      	datatype => 'string',
      	base_name => 'pivotFieldType',
-     	description => '',
+     	description => 'Represents PivotTable field type(Undefined/Row/Column/Page/Data).',
      	format => '',
      	read_only => '',
      		},
      'pivot_field' => {
      	datatype => 'PivotField',
      	base_name => 'pivotField',
-     	description => '',
+     	description => 'Represents pivot field.',
      	format => '',
      	read_only => '',
      		},
      'need_re_calculate' => {
      	datatype => 'string',
      	base_name => 'needReCalculate',
-     	description => '',
+     	description => 'Whether the specific PivotTable calculate(true/false).',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
