@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -60,14 +60,17 @@ sub new {
 
 # Run Operation Request
 # PostWorkbookSaveAsRequest.name : The workbook name.  ,
-# PostWorkbookSaveAsRequest.newfilename : The new file name.  ,
+# PostWorkbookSaveAsRequest.newfilename : newfilename to save the result.The `newfilename` should encompass both the filename and extension.  ,
 # PostWorkbookSaveAsRequest.saveOptions :   ,
 # PostWorkbookSaveAsRequest.isAutoFitRows : Indicates if Autofit rows in workbook.  ,
 # PostWorkbookSaveAsRequest.isAutoFitColumns : Indicates if Autofit columns in workbook.  ,
-# PostWorkbookSaveAsRequest.folder : Original workbook folder.  ,
-# PostWorkbookSaveAsRequest.storageName : Storage name.  ,
-# PostWorkbookSaveAsRequest.outStorageName :   ,
-# PostWorkbookSaveAsRequest.checkExcelRestriction :    
+# PostWorkbookSaveAsRequest.folder : The folder where the file is situated.  ,
+# PostWorkbookSaveAsRequest.storageName : The storage name where the file is situated.  ,
+# PostWorkbookSaveAsRequest.outStorageName : The storage name where the output file is situated.  ,
+# PostWorkbookSaveAsRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
+# PostWorkbookSaveAsRequest.region : The regional settings for workbook.  ,
+# PostWorkbookSaveAsRequest.pageWideFitOnPerSheet : The page wide fit on worksheet.  ,
+# PostWorkbookSaveAsRequest.pageTallFitOnPerSheet : The page tall fit on worksheet.   
 
 {
     my $params = {
@@ -78,7 +81,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_workbook_save_as' } = { 
-    	summary => 'Converts document and saves result to storage.',
+    	summary => 'Save an Excel file in various formats.',
         params => $params,
         returns => 'SaveResponse',
     };
@@ -134,6 +137,18 @@ sub run_http_request {
 
     if(defined $self->check_excel_restriction){
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
+    }
+
+    if(defined $self->region){
+        $query_params->{'region'} = $client->to_query_value($self->region);      
+    }
+
+    if(defined $self->page_wide_fit_on_per_sheet){
+        $query_params->{'pageWideFitOnPerSheet'} = $client->to_query_value($self->page_wide_fit_on_per_sheet);      
+    }
+
+    if(defined $self->page_tall_fit_on_per_sheet){
+        $query_params->{'pageTallFitOnPerSheet'} = $client->to_query_value($self->page_tall_fit_on_per_sheet);      
     } 
     my $_body_data;
 
@@ -162,7 +177,7 @@ __PACKAGE__->method_documentation({
      'newfilename' => {
      	datatype => 'string',
      	base_name => 'newfilename',
-     	description => 'The new file name.',
+     	description => 'newfilename to save the result.The `newfilename` should encompass both the filename and extension.',
      	format => '',
      	read_only => '',
      		},
@@ -190,28 +205,49 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'out_storage_name' => {
      	datatype => 'string',
      	base_name => 'outStorageName',
-     	description => '',
+     	description => 'The storage name where the output file is situated.',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => '',
+     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'region',
+     	description => 'The regional settings for workbook.',
+     	format => '',
+     	read_only => '',
+     		},
+     'page_wide_fit_on_per_sheet' => {
+     	datatype => 'string',
+     	base_name => 'pageWideFitOnPerSheet',
+     	description => 'The page wide fit on worksheet.',
+     	format => '',
+     	read_only => '',
+     		},
+     'page_tall_fit_on_per_sheet' => {
+     	datatype => 'string',
+     	base_name => 'pageTallFitOnPerSheet',
+     	description => 'The page tall fit on worksheet.',
      	format => '',
      	read_only => '',
      		},    
@@ -227,7 +263,10 @@ __PACKAGE__->attribute_map( {
     'folder' => 'folder',
     'storage_name' => 'storageName',
     'out_storage_name' => 'outStorageName',
-    'check_excel_restriction' => 'checkExcelRestriction' 
+    'check_excel_restriction' => 'checkExcelRestriction',
+    'region' => 'region',
+    'page_wide_fit_on_per_sheet' => 'pageWideFitOnPerSheet',
+    'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
