@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# PostWorkbookSettingsRequest.name :   ,
-# PostWorkbookSettingsRequest.settings :   ,
-# PostWorkbookSettingsRequest.folder :   ,
-# PostWorkbookSettingsRequest.storageName :    
+# PostWorkbookSettingsRequest.name : The file name.  ,
+# PostWorkbookSettingsRequest.settings : Workbook Setting description.  ,
+# PostWorkbookSettingsRequest.folder : The folder where the file is situated.  ,
+# PostWorkbookSettingsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_workbook_settings' } = { 
-    	summary => '',
+    	summary => 'Update setting in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -130,28 +130,28 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'settings' => {
      	datatype => 'WorkbookSettings',
      	base_name => 'settings',
-     	description => '',
+     	description => 'Workbook Setting description.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
