@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCalculateFormulaRequest.name :   ,
-# PostWorksheetCalculateFormulaRequest.sheetName :   ,
-# PostWorksheetCalculateFormulaRequest.formula :   ,
-# PostWorksheetCalculateFormulaRequest.folder :   ,
-# PostWorksheetCalculateFormulaRequest.storageName :    
+# PostWorksheetCalculateFormulaRequest.name : The file name.  ,
+# PostWorksheetCalculateFormulaRequest.sheetName : Worksheet name.  ,
+# PostWorksheetCalculateFormulaRequest.formula : The formula.  ,
+# PostWorksheetCalculateFormulaRequest.folder : The folder where the file is situated.  ,
+# PostWorksheetCalculateFormulaRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_calculate_formula' } = { 
-    	summary => '',
+    	summary => 'Calculate formula in the worksheet.',
         params => $params,
         returns => 'SingleValueResponse',
     };
@@ -135,35 +135,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'Worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'formula' => {
      	datatype => 'string',
      	base_name => 'formula',
-     	description => '',
+     	description => 'The formula.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
